@@ -11,6 +11,9 @@ pub struct Cli {
 
 #[derive(Subcommand)]
 pub enum Commands {
+    /// Displays information, such as architecture of a binary.
+    Info(info::Arguments),
+
     /// List different parts of a given binary.
     #[clap(subcommand)]
     List(list::Commands),
